Set

Struct Set 

pub struct Set {
    wait_jh: JoinHandle<usize>,
}
A set of running PubHubs servers.

Fields

wait_jh: JoinHandle<usize>

Handle to the task waiting on SetInner::wait.

Implementations

Source

impl Set

pub fn new(config: &Config) -> Result<(Self, Sender<Infallible>)>

Creates a new set of PubHubs servers from the given config. To signal shutdown of these senders, drop the returned sender.

pub async fn wait(self) -> usize

Waits for one of the servers to return, panic, or be cancelled. If that happens, the other servers are directed to shutdown as well.

Returns the number of servers that did not shutdown cleanly.

Panics when the tokio runtime is shut down.