pub struct SetOpts {
pub phc_listener: Option<TcpListener>,
pub transcryptor_listener: Option<TcpListener>,
pub auths_listener: Option<TcpListener>,
}Expand description
Additional options for Set::new_opts.
Used by the integration tests to run the servers on pre-bound, ephemeral ports, so that
multiple Sets can run simultaneously. Each listener is try_cloned (the file descriptor
is dup’d) every time its server (re)starts — e.g. after discovery — so the originals are kept
alive (by the Runner, for as long as the server runs) to keep the port reserved.
Fields
phc_listener: Option<TcpListener>If set, PubHubs Central listens on this pre-bound socket instead of binding the address in
its config. Its advertised phc_url must point at the same port (not checked at runtime).
transcryptor_listener: Option<TcpListener>Like SetOpts::phc_listener, but for the transcryptor.
auths_listener: Option<TcpListener>Like SetOpts::phc_listener, but for the authentication server.
Implementations
Sourceimpl SetOpts
impl SetOpts
Sourcefn take_listener(&mut self, name: Name) -> Option<TcpListener>
fn take_listener(&mut self, name: Name) -> Option<TcpListener>
Takes the pre-bound listener for the given server, if any.