pub struct Handle<S: Server> {
sender: Sender<CommandRequest<S>>,
discovery_limiter: DiscoveryLimiter,
}Expand description
Fields
sender: Sender<CommandRequest<S>>To send commands to the server
discovery_limiter: DiscoveryLimiterTo coordinate the handling of discovery requests
Implementations
Sourceimpl<S: Server> Handle<S>
impl<S: Server> Handle<S>
Sourcepub(crate) async fn issue_command(&self, command: Command<S>) -> Result<(), ()>
pub(crate) async fn issue_command(&self, command: Command<S>) -> Result<(), ()>
Issues command to Runner. Waits for the command to be next in line, but does not wait for the command to be completed.
May return Err(()) when another command shutdown the server before this
command could be executed.
When Ok(()) is returned, this means the command is guaranteed to be executed momentarily.
pub async fn modify( &self, display: impl Display + Send + 'static, modifier: impl FnOnce(&mut S) -> bool + Send + 'static, ) -> Result<(), ()>
Sourcepub async fn inspect<T: Send + 'static>(
&self,
display: impl Display + Send + 'static,
inspector: impl FnOnce(&S) -> T + Send + 'static,
) -> Result<T, ()>
pub async fn inspect<T: Send + 'static>( &self, display: impl Display + Send + 'static, inspector: impl FnOnce(&S) -> T + Send + 'static, ) -> Result<T, ()>
Executes inspector on the server instance, returning its result.
Returns Err(()) when the command or its result could not be sent, probably because the server was shutting down.
pub async fn request_discovery( &self, app: Rc<S::AppT>, ) -> Result<DiscoveryRunResp>