SetInner

Struct SetInner 

struct SetInner {
    joinset: JoinSet<Result<()>>,
    shutdown_sender: Option<Sender<Infallible>>,
    shutdown_receiver: Receiver<Infallible>,
}
A set of running PubHubs servers.

Fields

joinset: JoinSet<Result<()>>

The servers’ tasks

shutdown_sender: Option<Sender<Infallible>>

Via shutdown_sender Set broadcasts the instruction to shutdown to all servers running in the joinset. It does so not by sending a message, but by dropping the shutdown_sender.

shutdown_receiver: Receiver<Infallible>

Via shutdown_receiver, the Set received the instruction to close.

Implementations

Source

impl SetInner

pub fn new(config: &Config) -> Result<(Self, Sender<Infallible>)>

Creates a new set of PubHubs servers from the given config.

Returns not only the SetInner instance, but also a tokio::sync::oneshot::Sender<Infallible> that can be dropped to signal the SetInner should shutdown.

fn run_server<S: Server>( config: Config, rt_handle: Handle, shutdown_receiver: Receiver<Infallible>, worker_count: Option<NonZero<usize>>, ) -> Result<()>

pub async fn wait(self) -> usize

Waits for one of the servers to return, panic, or be cancelled. If that happens, the other servers are directed to shutdown as well.

If this function is not called, servers can fail silently.

Returns the number of servers that did not shutdown cleanly

pub async fn shutdown(self) -> usize

Requests shutdown of all servers, and wait for it to complete. Returns the number of servers that did not shutdown cleanly.